<?php

App::uses('PluginInstallShell', 'shells');
App::uses('File', 'Utility');

class EvCheckoutInstallShell extends PluginInstallShell {

	public $uses = array(
		'EvTemplates.Template',
		'EvCore.Page',
		'EvCheckout.OrderStatus'
	);

	/**
	 * call parent run() This will auto run any migrations
	 *
	 * Use the run() method here to insert any content
	 */
	public function run() {
		parent::run();

		$date = date('Y-m-d H:i:s');

		// add all the base temoplates
		$this->Template->saveMany(
			array(
				array(
					'Template' => array(
						'name' => 'Order Successful',
						'template' => 'EvCheckout./Templates/Order/successful',
						'helperFunction' => 'N/A',
						'cfDataLabel' => 'Custom Data',
						'model' => 'Page',
						'is_active' => 1,
						'created' => $date,
						'modified' => $date
					)
				),
				array(
					'Template' => array(
						'name' => 'Order Failed',
						'template' => 'EvCheckout./Templates/Order/fail',
						'helperFunction' => 'N/A',
						'cfDataLabel' => 'Custom Data',
						'model' => 'Page',
						'is_active' => 1,
						'created' => $date,
						'modified' => $date
					)
				),
				array(
					'Template' => array(
						'name' => 'Order Cancelled',
						'template' => 'EvCheckout./Templates/Order/cancelled',
						'helperFunction' => 'N/A',
						'cfDataLabel' => 'Custom Data',
						'model' => 'Page',
						'is_active' => 1,
						'created' => $date,
						'modified' => $date
					)
				)
			)
		);
		$templateIds = $this->Template->find('list', array('callbacks' => false, 'limit' => 3, 'order' => 'Template.id DESC'));
		$templateIds = array_flip($templateIds);

		// add the pages for the index
		$this->Page->saveMany(
			array(
				array(
					'Page' => array(
						'title' => 'Order Successful',
						'body' => '<p>Your order (#ORDERID) was placed successfully. You shall receive a confirmation email shortly.</p>',
						'is_active' => 1,
						'is_protected' => 1,
						'template_id' => $templateIds['Order Successful'],
						'created' => $date,
						'modified' => $date
					)
				),
				array(
					'Page' => array(
						'title' => 'Order Failed',
						'body' => '<p>There was a problem completing your order, please try again. If the problem persists, please contact us.</p>',
						'is_active' => 1,
						'is_protected' => 1,
						'template_id' => $templateIds['Order Failed'],
						'created' => $date,
						'modified' => $date
					)
				),
				array(
					'Page' => array(
						'title' => 'Order Cancelled',
						'body' => '<p>The checkout process was cancelled.</p>',
						'is_active' => 1,
						'is_protected' => 1,
						'template_id' => $templateIds['Order Cancelled'],
						'created' => $date,
						'modified' => $date
					)
				)
			)
		);
		$pageIds = $this->Page->find('list', array('callbacks' => false, 'limit' => 3, 'order' => 'Page.id DESC'));
		$pageIds = array_flip($pageIds);

		// write to the plugin config
		$configContents = '<?php

$config = array(
	\'EvCheckout\' => array(
		/**
		 * pageIds for success / fail pages
		 */
		\'pageIds\' => array(
			\'success\' => ' . $pageIds['Order Successful'] . ',
			\'fail\' => ' . $pageIds['Order Failed'] . ',
			\'cancel\' => ' . $pageIds['Order Cancelled'] . '
		)
	)
);';

		$File = new File(APP . 'Config/Plugin/ev_checkout.php', true);
		$File->write($configContents);

		$this->OrderStatus->saveMany(
			array(
				array(
					'OderStatus' => array(
						'name' => 'Awaiting Payment',
						'sequence' => 10,
						'is_active' => 1,
						'created' => $date,
						'modified' => $date
					)
				),
				array(
					'OderStatus' => array(
						'name' => 'Paid',
						'sequence' => 20,
						'is_active' => 1,
						'created' => $date,
						'modified' => $date
					)
				),
				array(
					'OderStatus' => array(
						'name' => 'Shipped',
						'sequence' => 30,
						'is_active' => 1,
						'created' => $date,
						'modified' => $date
					)
				)
			)
		);
	}
}
