<?php

App::uses('EvCheckoutAppController', 'EvCheckout.Controller');
App::uses('ArrayUtil', 'EvCore.Lib');

class OrdersController extends EvCheckoutAppController {

	public function beforeFilter() {
		parent::beforeFilter();

		$this->Auth->allow(array('complete', 'cancel'));
	}

	/**
	 * complete an order
	 * this could display success or fail messages.
	 * This is where the payment is checked and turned into an order
	 *
	 */
	public function complete() {
		if (CakePlugin::loaded('EvTransactions') && ! empty($this->request->query['transaction'])) {
			$this->TransactionsManager = $this->loadComponent('EvTransactions.Transactions');
			$this->OrderManager = $this->loadComponent('EvCheckout.OrderManager');

			if ($this->TransactionsManager->checkPayment()) {
				$orderId = $this->OrderManager->buildOrder($this->request->query['transaction']);

				// call hooks
				// add email to queue
				$this->view = 'EvCheckout./Fallbacks/Order/success';
				$pageId = Configure::read('EvCheckout.pageIds.success');
			} else {

				$this->view = 'EvCheckout./Fallbacks/Order/fail';
				$pageId = Configure::read('EvCheckout.pageIds.fail');
			}
		}

		if (empty($this->view)) {
			$this->view = 'EvCheckout./Fallbacks/Order/fail';
			$pageId = Configure::read('EvCheckout.pageIds.fail');
		}

		// check if we have a specific content page set
		// if so - set the template
		if (! empty($pageId)) {
			$pageData = $this->assignPage($pageId);

			if (! empty($pageData)) {
				if (! empty($orderId)) {
					$pageData['Page']['title'] = str_replace('ORDERID', $orderId, $pageData['Page']['title']);
					$pageData['Page']['body'] = str_replace('ORDERID', $orderId, $pageData['Page']['body']);
					$this->set('data', $pageData);
				}

				$this->view = $this->Tpl->getTemplate($pageData, 'Page');
			}
		}
	}

	/**
	 * cancel an order.
	 * usually used on gateways for the "cancel and return to store" links
	 *
	 */
	public function cancel() {
		if (CakePlugin::loaded('EvTransactions') && ! empty($this->request->query['transaction'])) {
			$this->TransactionsManager = $this->loadComponent('EvTransactions.Transactions');

			$this->TransactionsManager->failTransaction(
				$this->request->query['transaction'],
				'The order was cancelled by the user'
			);
		}

		$this->view = 'EvCheckout./Fallbacks/Order/cancel';
		$pageId = Configure::read('EvCheckout.pageIds.cancel');

		// check if we have a specific content page set
		// if so - set the template
		if (! empty($pageId)) {
			$pageData = $this->assignPage($pageId);

			if (! empty($pageData)) {
				$this->view = $this->Tpl->getTemplate($pageData, 'Page');
			}
		}
	}

	/**
	 * redefine index columns
	 * to add more order info
	 */
	protected function _adminIndexColumns() {
		$columns = parent::_adminIndexColumns();

		$columns = ArrayUtil::addAfter(
			$columns,
			'Order.name',
			array(
				'Order.email' => array(
					'type' => 'string',
					'label' => __('Email')
				),
				'Order.phone' => array(
					'type' => 'string',
					'label' => __('Phone')
				),
				'OrderStatus.name' => array(
					'type' => 'string',
					'label' => __('Status')
				),
				'Order.is_paid' => array(
					'type' => 'display_boolean',
					'label' => __('Paid')
				)
			)
		);

		unset($columns['Order.modified']);
		return $columns;
	}

	/*
		----------------------------------------------------------------
		Admin methods
		----------------------------------------------------------------
	*/

	/**
	 * redefine index paginate
	 * to contain status
	 */
	protected function _adminIndexPaginate() {
		$paginate = parent::_adminIndexPaginate();

		$paginate['contain'][] = 'OrderStatus';
		$paginate['order'] = 'Order.id DESC';

		return $paginate;
	}

	/**
	 * define index filters
	 * to make it more usable
	 *
	 */
	protected function _adminFilterFields() {
		$fields = parent::_adminFilterFields();

		$fields = ArrayUtil::addAfter(
			$fields,
			'Order.name',
			array(
				'Order.email' => array(
					'label' => __('Email'),
					'type' => 'string',
					'compare' => array(
						'Order.email LIKE' => '%%%s%%'
					)
				),
				'Order.order_status_id' => array(
					'label' => __('Status'),
					'type' => 'select',
					'compare' => array(
						'Order.order_status_id' => '%s'
					)
				),
				'Order.is_paid' => array(
					'label' => __('Paid'),
					'type' => 'select',
					'compare' => array(
						'Order.is_paid' => '%s'
					)
				)
			)
		);

		unset($fields['Order.modified']);

		return $fields;
	}

	/**
	 * redefine filter populate
	 * to bring in order status list
	 *
	 */
	protected function _adminPopulateFilterLookups() {
		$OrderStatus = EvClassRegistry::init('EvCheckout.OrderStatus');

		$this->set(
			'orderStatuses',
			$OrderStatus->getForDropDown()
		);

		$this->set(
			'isPaids',
			array(
				'1' => __('Yes'),
				'0' => __('No')
			)
		);
	}
}
